@@ -179,6 +179,9 @@ class Config(object):
 		config += "\n    HostName {}".format(ip)
 		config += "\n    Port {}".format(port)
 		config += "\n    User {}".format(username)
+		config += "\n    ForwardAgent yes"
+		config += "\n    PubKeyAuthentication yes"
+		#config += "\n    IdentitiesOnly yes"
 		if not smart_card:
 			config += "\n    IdentityFile {}".format(key)
 		else:
@@ -885,7 +888,8 @@ class Agent(object):
 					os.system(f"cp {path} {copy_path}")
 					path = copy_path
 				file = Files.File(path="/tmp/shell.sh")
-				file.save(f'export SSH_AUTH_SOCK={self.SSH_AUTH_SOCK}\nexport SSH_AGENT_PID={self.SSH_AGENT_PID}\nssh-add -e {path}\nssh-add -s {path}')
+				#file.save(f'export SSH_AUTH_SOCK={self.SSH_AUTH_SOCK}\nexport SSH_AGENT_PID={self.SSH_AGENT_PID}\nssh-add -e {path}\nssh-add -s {path}')
+				file.save(f'ssh-add -e {path}\nssh-add -s {path}')
 				#file.save(f'ssh-add -s {path}')
 				file.file_path.permission.set(755)
 				spawn = pexpect.spawn(f'sh {file.file_path.path}')
@@ -1075,7 +1079,7 @@ class Agent(object):
 		return response
 
 def __create_base__():
-	#return []
+	return []
 	path = "/tmp/shell_source.sh"
 	utils.__save_file__(path, f"#!/bin/sh\nSSH_AUTH_SOCK={agent.SSH_AUTH_SOCK}; export SSH_AUTH_SOCK;\nSSH_AGENT_PID={agent.SSH_AGENT_PID}; export SSH_AGENT_PID\n")
 	utils.__set_file_path_permission__(path, permission=755)
